#
# spec file for package perl-Mail-Message
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Mail-Message
Name:           perl-Mail-Message
Version:        3.16.0
Release:        1.1
# 3.016 -> normalize -> 3.16.0
%define cpan_version 3.016
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Processing MIME messages
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MARKOV/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Date::Format)
BuildRequires:  perl(Date::Parse)
BuildRequires:  perl(Encode) >= 2.26
BuildRequires:  perl(IO::Scalar)
BuildRequires:  perl(MIME::Types) >= 1.004
BuildRequires:  perl(Mail::Address) >= 2.17
BuildRequires:  perl(Time::Zone)
BuildRequires:  perl(URI) >= 1.23
BuildRequires:  perl(User::Identity) >= 1.02
Requires:       perl(Date::Format)
Requires:       perl(Date::Parse)
Requires:       perl(Encode) >= 2.26
Requires:       perl(IO::Scalar)
Requires:       perl(MIME::Types) >= 1.004
Requires:       perl(Mail::Address) >= 2.17
Requires:       perl(Time::Zone)
Requires:       perl(URI) >= 1.23
Requires:       perl(User::Identity) >= 1.02
Provides:       perl(Mail::Box::FastScalar) = %{version}
Provides:       perl(Mail::Box::Parser) = %{version}
Provides:       perl(Mail::Box::Parser::Perl) = %{version}
Provides:       perl(Mail::Message) = %{version}
Provides:       perl(Mail::Message::Body) = %{version}
Provides:       perl(Mail::Message::Body::File) = %{version}
Provides:       perl(Mail::Message::Body::Lines) = %{version}
Provides:       perl(Mail::Message::Body::Multipart) = %{version}
Provides:       perl(Mail::Message::Body::Nested) = %{version}
Provides:       perl(Mail::Message::Body::String) = %{version}
Provides:       perl(Mail::Message::Convert) = %{version}
Provides:       perl(Mail::Message::Convert::EmailSimple) = %{version}
Provides:       perl(Mail::Message::Convert::Html) = %{version}
Provides:       perl(Mail::Message::Convert::HtmlFormatPS) = %{version}
Provides:       perl(Mail::Message::Convert::HtmlFormatText) = %{version}
Provides:       perl(Mail::Message::Convert::MailInternet) = %{version}
Provides:       perl(Mail::Message::Convert::MimeEntity) = %{version}
Provides:       perl(Mail::Message::Convert::TextAutoformat) = %{version}
Provides:       perl(Mail::Message::Field) = %{version}
Provides:       perl(Mail::Message::Field::AddrGroup) = %{version}
Provides:       perl(Mail::Message::Field::Address) = %{version}
Provides:       perl(Mail::Message::Field::Addresses) = %{version}
Provides:       perl(Mail::Message::Field::Attribute) = %{version}
Provides:       perl(Mail::Message::Field::AuthResults) = %{version}
Provides:       perl(Mail::Message::Field::DKIM) = %{version}
Provides:       perl(Mail::Message::Field::Date) = %{version}
Provides:       perl(Mail::Message::Field::Fast) = %{version}
Provides:       perl(Mail::Message::Field::Flex) = %{version}
Provides:       perl(Mail::Message::Field::Full) = %{version}
Provides:       perl(Mail::Message::Field::Structured) = %{version}
Provides:       perl(Mail::Message::Field::URIs) = %{version}
Provides:       perl(Mail::Message::Field::Unstructured) = %{version}
Provides:       perl(Mail::Message::Head) = %{version}
Provides:       perl(Mail::Message::Head::Complete) = %{version}
Provides:       perl(Mail::Message::Head::FieldGroup) = %{version}
Provides:       perl(Mail::Message::Head::ListGroup) = %{version}
Provides:       perl(Mail::Message::Head::Partial) = %{version}
Provides:       perl(Mail::Message::Head::ResentGroup) = %{version}
Provides:       perl(Mail::Message::Head::SpamGroup) = %{version}
Provides:       perl(Mail::Message::Part) = %{version}
Provides:       perl(Mail::Message::Replace::MailHeader) = %{version}
Provides:       perl(Mail::Message::Replace::MailInternet) = %{version}
Provides:       perl(Mail::Message::Test) = %{version}
Provides:       perl(Mail::Message::TransferEnc) = %{version}
Provides:       perl(Mail::Message::TransferEnc::Base64) = %{version}
Provides:       perl(Mail::Message::TransferEnc::Binary) = %{version}
Provides:       perl(Mail::Message::TransferEnc::EightBit) = %{version}
Provides:       perl(Mail::Message::TransferEnc::QuotedPrint) = %{version}
Provides:       perl(Mail::Message::TransferEnc::SevenBit) = %{version}
Provides:       perl(Mail::Reporter) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
A 'Mail::Message' object is a container for MIME-encoded message
information, as defined by RFC2822. Everything what is not specificaly
related to storing the messages in mailboxes (folders) is implemented in
this class. Methods which are related to folders is implemented in the
Mail::Box::Message extension.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ChangeLog README README.md

%changelog
* Thu Dec 12 2024 Tina Müller <timueller+perl@suse.de>
- updated to 3.16.0 (3.016)
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
  version 3.016: Wed 27 Nov 10:53:40 CET 2024
  Changes:
  - when (illegally) multiple attributes with the same name are used
  in a single header line, then the last is returned.  Just like
  Apple and Outlook do.  Originally returned the first.
  github issue 20 [Todd Richmond]
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Thu Dec 14 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.015
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
  version 3.015: Mon 11 Dec 09:58:17 CET 2023
  Fixes:
  - accept empty fields without complaint. [Andy Beverley]
  - fix counting epilogue trailing blank [Gregor Herrmann] GitHub#18, RT#150141
* Thu Oct 19 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.014
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
  version 3.014: Wed 18 Oct 12:16:55 CEST 2023
  Changes:
  - handle utf8 in address phrases, according to RFC5335 (since
  2008 experimental)  May show some changes in your regression
  tests.  [Andy Beverley]
  Fixes:
  - epilogue starter test needs ^ anchor
  github issue #16 [Jacob Balazer]
  - existing preamble should keep at least one empty string to
  indicate its existence.
  github issue #18 [Jacob Balazer]
  - clean error when field names are too long w.r.t. the fold
  wrap.  Found by [Raphaël Gertz]
* Sun Jun 25 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.013
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
* Sat Feb 12 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.012
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
  version 3.012: Fri 11 Feb 11:34:31 CET 2022
  Fixes:
  - ::Field::Attributes should be stored case intensively
  rt.cpan.org#140894 [Yanyan Yang]
  - ::Field::Full phrase with encoding qp parsing failed when
  the qp contains non-atext characters. Github#2 [Andy Beverley]
  - ::Field::Full QP encoding must be more strict for use in
  MIME headers.  Github#3 [Andy Beverley]
  - Coercion from Mail::Address to Mail::Message::Full::Address
  is too lazy.  Github#4 [Andy Beverley]
  Improvements:
  - extend date in mbox-separator to accept 203X as well.
* Wed Jul 28 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.011
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
  version 3.011: Tue 27 Jul 13:30:38 CEST 2021
  Improvements:
  - textAlternativeForHtml can now be configured to actually change
  left- and rightmargin [Tristan Miller]
* Mon Nov 23 2020 Frank Schreiner <FSchreiner@suse.com>
- Boiled down %%description to relevant infos
* Thu Oct 15 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.010
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
  version 3.010: Wed 14 Oct 19:22:36 CEST 2020
  Fixes:
  - username of address as quoted-string. [Andy Beverley]
* Sat Feb  8 2020 <timueller+perl@suse.de>
- updated to 3.009
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
  version 3.009: Fri  7 Feb 15:22:18 CET 2020
  Fixes:
  - avoid folding inside phrases.  Also, encode more characters.
  Reported by [Andrew Beverley]
* Tue Feb 12 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.008
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
* Wed Sep 19 2018 Stephan Kulow <coolo@suse.com>
- updated to 3.007
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
* Wed Feb  7 2018 coolo@suse.com
- updated to 3.006
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
  version 3.006: Wed 24 Jan 16:55:26 CET 2018
  Improvements:
  - spell corrections rt.cpan.org #123993 [Damyan Ivanov, debian]
  - add some 'use warnings'
  - convert to GIT
  - publish on GitHUB
* Sat Dec 23 2017 coolo@suse.com
- updated to 3.005
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
  version 3.005: Fri 22 Dec 09:43:45 CET 2017
  Fixes:
  - repair loose dependency on Mail::Transport [cpantesters]
* Fri Dec 22 2017 coolo@suse.com
- updated to 3.004
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
  version 3.004: Thu 21 Dec 09:08:52 CET 2017
  Fixes:
  - field unfold replaces leading whitespace into blank. [Mark Nienberg]
  Improvements:
  - improve docs on $msg->send().
* Thu Nov  9 2017 coolo@suse.com
- updated to 3.003
  see /usr/share/doc/packages/perl-Mail-Message/ChangeLog
  version 3.003: Wed  8 Nov 13:02:24 CET 2017
  Fixes:
  - incorrect use of reftype.   rt.cpan.org#121244 [Matthew Darwin]
  - missing 'use warnings' in ::Build
* Wed Oct 18 2017 coolo@suse.com
- initial package 3.002
  * created by cpanspec 1.78.08
